@@ -14,38 +14,38 @@ class Puppet::Application::Ssl < Puppet::Application
     <<~HELP
       puppet-ssl(8) -- #{summary}
       ========
-      
+
       SYNOPSIS
       --------
       Manage SSL keys and certificates for SSL clients needing
       to communicate with a puppet infrastructure.
-      
+
       USAGE
       -----
       puppet ssl <action> [-h|--help] [-v|--verbose] [-d|--debug] [--localca] [--target CERTNAME]
-      
-      
+
+
       OPTIONS
       -------
-      
+
       * --help:
         Print this help message.
-      
+
       * --verbose:
         Print extra information.
-      
+
       * --debug:
         Enable full debugging.
-      
+
       * --localca
         Also clean the local CA certificate and CRL.
-      
+
       * --target CERTNAME
         Clean the specified device certificate instead of this host's certificate.
-      
+
       ACTIONS
       -------
-      
+
       * bootstrap:
         Perform all of the steps necessary to request and download a client
         certificate. If autosigning is disabled, then puppet will wait every
@@ -53,34 +53,34 @@ class Puppet::Application::Ssl < Puppet::Application
         once and never wait, specify a time of 0. Since `waitforcert` is a
         Puppet setting, it can be specified as a time interval, such as 30s,
         5m, 1h.
-      
+
       * submit_request:
         Generate a certificate signing request (CSR) and submit it to the CA. If
         a private and public key pair already exist, they will be used to generate
         the CSR. Otherwise a new key pair will be generated. If a CSR has already
         been submitted with the given `certname`, then the operation will fail.
-      
+
       * generate_request:
         Generate a certificate signing request (CSR). If
         a private and public key pair already exist, they will be used to generate
         the CSR. Otherwise a new key pair will be generated.
-      
+
       * download_cert:
         Download a certificate for this host. If the current private key matches
         the downloaded certificate, then the certificate will be saved and used
         for subsequent requests. If there is already an existing certificate, it
         will be overwritten.
-      
+
       * verify:
         Verify the private key and certificate are present and match, verify the
         certificate is issued by a trusted CA, and check revocation status.
-      
+
       * clean:
         Remove the private key and certificate related files for this host. If
         `--localca` is specified, then also remove this host's local copy of the
         CA certificate(s) and CRL bundle. if `--target CERTNAME` is specified, then
         remove the files for the specified device on this host instead of this host.
-      
+
        * show:
         Print the full-text version of this host's certificate.
     HELP
@@ -149,7 +149,7 @@ class Puppet::Application::Ssl < Puppet::Application
     when 'clean'
       possible_extra_args = command_line.args.drop(1)
       unless possible_extra_args.empty?
-        raise Puppet::Error, _(<<~END) % { args: possible_extra_args.join(' ')}
+        raise Puppet::Error, _(<<~END) % { args: possible_extra_args.join(' ') }
           Extra arguments detected: %{args}
           Did you mean to run:
             puppetserver ca clean --certname <name>
@@ -160,7 +160,7 @@ class Puppet::Application::Ssl < Puppet::Application
 
       clean(certname)
     when 'bootstrap'
-      if !Puppet::Util::Log.sendlevel?(:info)
+      unless Puppet::Util::Log.sendlevel?(:info)
         Puppet::Util::Log.level = :info
       end
       @machine.ensure_client_certificate
@@ -192,7 +192,7 @@ class Puppet::Application::Ssl < Puppet::Application
     Puppet.notice _("Submitted certificate request for '%{name}' to %{url}") % { name: Puppet[:certname], url: route.url }
   rescue Puppet::HTTP::ResponseError => e
     if e.response.code == 400
-      raise Puppet::Error.new(_("Could not submit certificate request for '%{name}' to %{url} due to a conflict on the server") % { name: Puppet[:certname], url: route.url })
+      raise Puppet::Error, _("Could not submit certificate request for '%{name}' to %{url} due to a conflict on the server") % { name: Puppet[:certname], url: route.url }
     else
       raise Puppet::Error.new(_("Failed to submit certificate request: %{message}") % { message: e.message }, e)
     end
@@ -234,7 +234,7 @@ class Puppet::Application::Ssl < Puppet::Application
     cert
   rescue Puppet::HTTP::ResponseError => e
     if e.response.code == 404
-      return nil
+      nil
     else
       raise Puppet::Error.new(_("Failed to download certificate: %{message}") % { message: e.message }, e)
     end
