@@ -1,8 +1,10 @@
+# frozen_string_literal: true
+
 # The client for interacting with the puppetmaster config server.
 require 'timeout'
 require_relative '../puppet/util'
 require 'securerandom'
-#require 'puppet/parser/script_compiler'
+# require 'puppet/parser/script_compiler'
 require_relative '../puppet/pops/evaluator/deferred_resolver'
 
 class Puppet::Configurer
@@ -39,7 +41,7 @@ class Puppet::Configurer
 
   # Initialize and load storage
   def init_storage
-      Puppet::Util::Storage.load
+    Puppet::Util::Storage.load
   rescue => detail
     Puppet.log_exception(detail, _("Removing corrupt state file %{file}: %{detail}") % { file: Puppet[:statefile], detail: detail })
     begin
@@ -81,8 +83,8 @@ class Puppet::Configurer
     else
       result = retrieve_new_catalog(facts, query_options)
 
-      if !result
-        if !Puppet[:usecacheonfailure]
+      unless result
+        unless Puppet[:usecacheonfailure]
           Puppet.warning _("Not using cache on failed catalog")
           return nil
         end
@@ -142,7 +144,7 @@ class Puppet::Configurer
   end
 
   def warn_fact_value_length(value, max_length)
-    Puppet.warning _("Fact value '%{value}' with the value length: '%{length}' exceeds the value length limit: %{max_length}") % { value: value, length:value.to_s.bytesize, max_length: max_length }
+    Puppet.warning _("Fact value '%{value}' with the value length: '%{length}' exceeds the value length limit: %{max_length}") % { value: value, length: value.to_s.bytesize, max_length: max_length }
   end
 
   def warn_fact_payload_size(payload, max_size)
@@ -153,7 +155,7 @@ class Puppet::Configurer
     max_length = Puppet[:fact_name_length_soft_limit]
     return if max_length.zero?
 
-    # rough byte size estimations of fact path as a postgresql btree index 
+    # rough byte size estimations of fact path as a postgresql btree index
     size_as_btree_index = 8 + (number_of_dots * 2) + name.to_s.bytesize
     warn_fact_name_length(name, max_length) if size_as_btree_index > max_length
   end
@@ -184,7 +186,7 @@ class Puppet::Configurer
     return if max_size.zero?
 
     warn_fact_payload_size(payload, max_size) if payload > max_size
-    Puppet.debug _("The size of the payload is %{payload}") % {payload: payload}
+    Puppet.debug _("The size of the payload is %{payload}") % { payload: payload }
   end
 
   def parse_fact_name_and_value_limits(object, path = [])
@@ -214,7 +216,7 @@ class Puppet::Configurer
 
     parse_fact_name_and_value_limits(facts)
     check_total_number_limit(@number_of_facts)
-    Puppet.debug _("The total number of facts registered is %{number_of_facts}") % {number_of_facts: @number_of_facts}
+    Puppet.debug _("The total number of facts registered is %{number_of_facts}") % { number_of_facts: @number_of_facts }
   end
 
   def get_facts(options)
@@ -271,7 +273,7 @@ class Puppet::Configurer
   end
 
   def prepare_and_retrieve_catalog_from_cache(options = {})
-    result = retrieve_catalog_from_cache({:transaction_uuid => @transaction_uuid, :static_catalog => @static_catalog})
+    result = retrieve_catalog_from_cache({ :transaction_uuid => @transaction_uuid, :static_catalog => @static_catalog })
     Puppet.info _("Using cached catalog from environment '%{catalog_env}'") % { catalog_env: result.environment } if result
     result
   end
@@ -328,7 +330,7 @@ class Puppet::Configurer
             raise Puppet::Error, detail
           end
         else
-          #TRANSLATORS 'server_list' is the name of a setting and should not be translated
+          # TRANSLATORS 'server_list' is the name of a setting and should not be translated
           Puppet.debug _("Selected puppet server from the `server_list` setting: %{server}:%{port}") % { server: server, port: port }
           report.server_used = "#{server}:#{port}"
         end
@@ -388,7 +390,7 @@ class Puppet::Configurer
       configured_environment = Puppet[:environment] if Puppet.settings.set_by_config?(:environment)
 
       # We only need to find out the environment to run in if we don't already have a catalog
-      unless (cached_catalog || options[:catalog] || Puppet.settings.set_by_cli?(:environment) || Puppet[:strict_environment_mode])
+      unless cached_catalog || options[:catalog] || Puppet.settings.set_by_cli?(:environment) || Puppet[:strict_environment_mode]
         Puppet.debug(_("Environment not passed via CLI and no catalog was given, attempting to find out the last server-specified environment"))
         initial_environment, loaded_last_environment = last_server_specified_environment
 
@@ -440,10 +442,11 @@ class Puppet::Configurer
       # facts may be used to determine which catalog we get, we need to
       # rerun the process if the environment is changed.
       tries = 0
-      while catalog.environment and not catalog.environment.empty? and catalog.environment != @environment
+      while catalog.environment and !catalog.environment.empty? and catalog.environment != @environment
         if tries > 3
           raise Puppet::Error, _("Catalog environment didn't stabilize after %{tries} fetches, aborting run") % { tries: tries }
         end
+
         Puppet.notice _("Local environment: '%{local_env}' doesn't match server specified environment '%{catalog_env}', restarting agent run with environment '%{catalog_env}'") % { local_env: @environment, catalog_env: catalog.environment }
         @environment = catalog.environment
         report.environment = @environment
@@ -456,6 +459,7 @@ class Puppet::Configurer
         # if we get here, ignore the cached catalog
         catalog = prepare_and_retrieve_catalog(nil, facts, options, query_options)
         return nil unless catalog
+
         tries += 1
       end
 
@@ -501,9 +505,9 @@ class Puppet::Configurer
       true
     rescue => detail
       Puppet.log_exception(detail, _("Failed to apply catalog: %{detail}") % { detail: detail })
-      return nil
+      nil
     ensure
-      execute_postrun_command or return nil
+      execute_postrun_command or return nil # rubocop:disable Lint/EnsureReturn
     end
   ensure
     if Puppet[:resubmit_facts]
@@ -527,12 +531,12 @@ class Puppet::Configurer
     session = Puppet.lookup(:http_session)
     begin
       fs = session.route_to(:fileserver)
-      fs.get_file_metadatas(path: URI(Puppet[:pluginsource]).path, recurse: :false, environment: @environment)
+      fs.get_file_metadatas(path: URI(Puppet[:pluginsource]).path, recurse: :false, environment: @environment) # rubocop:disable Lint/BooleanSymbol
       true
     rescue Puppet::HTTP::ResponseError => detail
       if detail.response.code == 404
         if Puppet[:strict_environment_mode]
-          raise Puppet::Error.new(_("Environment '%{environment}' not found on server, aborting run.") % { environment: @environment })
+          raise Puppet::Error, _("Environment '%{environment}' not found on server, aborting run.") % { environment: @environment }
         else
           Puppet.notice(_("Environment '%{environment}' not found on server, skipping initial pluginsync.") % { environment: @environment })
         end
@@ -555,8 +559,8 @@ class Puppet::Configurer
       Puppet.debug(_("Puppet server %{host}:%{port} is unavailable: %{code} %{reason}") %
                    { host: e.response.url.host, port: e.response.url.port, code: e.response.code, reason: e.response.reason })
     rescue => detail
-      #TRANSLATORS 'server_list' is the name of a setting and should not be translated
-      Puppet.debug _("Unable to connect to server from server_list setting: %{detail}") % {detail: detail}
+      # TRANSLATORS 'server_list' is the name of a setting and should not be translated
+      Puppet.debug _("Unable to connect to server from server_list setting: %{detail}") % { detail: detail }
     end
     [nil, nil]
   end
@@ -578,6 +582,7 @@ class Puppet::Configurer
     if Puppet::FileSystem.exist?(Puppet[:lastrunfile])
       summary = Puppet::Util::Yaml.safe_load_file(Puppet[:lastrunfile])
       return [nil, nil] unless summary['application']['run_mode'] == 'agent'
+
       initial_environment = summary['application']['initial_environment']
       converged_environment = summary['application']['converged_environment']
       @last_server_specified_environment = converged_environment if initial_environment != converged_environment
@@ -664,17 +669,18 @@ class Puppet::Configurer
     puppet = session.route_to(:puppet)
 
     Puppet.info(_("Uploading facts for %{node} to %{server}") % {
-                  node: facts.name,
-                  server: puppet.url.hostname})
+      node: facts.name,
+      server: puppet.url.hostname
+    })
 
     puppet.put_facts(facts.name, facts: facts, environment: Puppet.lookup(:current_environment).name.to_s)
 
-    return true
+    true
   rescue => detail
     Puppet.log_exception(detail, _("Failed to submit facts: %{detail}") %
                                  { detail: detail })
 
-    return false
+    false
   end
 
   private
@@ -709,14 +715,14 @@ class Puppet::Configurer
         Puppet[:node_name_value],
         query_options.merge(
           :ignore_terminus => true,
-          :environment     => Puppet::Node::Environment.remote(@environment)
+          :environment => Puppet::Node::Environment.remote(@environment)
         )
       )
     end
     result
   rescue => detail
     Puppet.log_exception(detail, _("Could not retrieve catalog from cache: %{detail}") % { detail: detail })
-    return nil
+    nil
   end
 
   def retrieve_new_catalog(facts, query_options)
@@ -725,12 +731,12 @@ class Puppet::Configurer
       result = Puppet::Resource::Catalog.indirection.find(
         Puppet[:node_name_value],
         query_options.merge(
-          :ignore_cache      => true,
+          :ignore_cache => true,
           # don't update cache until after environment converges
           :ignore_cache_save => true,
-          :environment       => Puppet::Node::Environment.remote(@environment),
+          :environment => Puppet::Node::Environment.remote(@environment),
           :check_environment => true,
-          :fail_on_404       => true,
+          :fail_on_404 => true,
           :facts_for_catalog => facts
         )
       )
@@ -738,18 +744,16 @@ class Puppet::Configurer
     result
   rescue StandardError => detail
     Puppet.log_exception(detail, _("Could not retrieve catalog from remote server: %{detail}") % { detail: detail })
-    return nil
+    nil
   end
 
   def download_plugins(remote_environment_for_plugins)
-    begin
-      @handler.download_plugins(remote_environment_for_plugins)
-    rescue Puppet::Error => detail
-      if !Puppet[:ignore_plugin_errors] && Puppet[:usecacheonfailure]
-        @running_failure = true
-      else
-        raise detail
-      end
+    @handler.download_plugins(remote_environment_for_plugins)
+  rescue Puppet::Error => detail
+    if !Puppet[:ignore_plugin_errors] && Puppet[:usecacheonfailure]
+      @running_failure = true
+    else
+      raise detail
     end
   end
 end
