@@ -27,15 +27,17 @@ Puppet::Type.type(:file).provide :posix do
     end
 
     if user.uid == ""
-      return nil
+      nil
     else
-      return user.name
+      user.name
     end
   end
 
   # Determine if the user is valid, and if so, return the UID
   def name2uid(value)
-    Integer(value) rescue uid(value) || false
+    Integer(value)
+  rescue
+    uid(value) || false
   end
 
   def gid2name(id)
@@ -49,14 +51,16 @@ Puppet::Type.type(:file).provide :posix do
     end
 
     if group.gid == ""
-      return nil
+      nil
     else
-      return group.name
+      group.name
     end
   end
 
   def name2gid(value)
-    Integer(value) rescue gid(value) || false
+    Integer(value)
+  rescue
+    gid(value) || false
   end
 
   def owner
@@ -71,7 +75,7 @@ Puppet::Type.type(:file).provide :posix do
     # large UIDs instead of negative ones.  This isn't a Ruby bug,
     # it's an OS X bug, since it shows up in perl, too.
     if currentvalue > Puppet[:maximum_uid].to_i
-      self.warning _("Apparently using negative UID (%{currentvalue}) on a platform that does not consistently handle them") % { currentvalue: currentvalue }
+      warning _("Apparently using negative UID (%{currentvalue}) on a platform that does not consistently handle them") % { currentvalue: currentvalue }
       currentvalue = :silly
     end
 
@@ -103,7 +107,7 @@ Puppet::Type.type(:file).provide :posix do
     # large GIDs instead of negative ones.  This isn't a Ruby bug,
     # it's an OS X bug, since it shows up in perl, too.
     if currentvalue > Puppet[:maximum_uid].to_i
-      self.warning _("Apparently using negative GID (%{currentvalue}) on a platform that does not consistently handle them") % { currentvalue: currentvalue }
+      warning _("Apparently using negative GID (%{currentvalue}) on a platform that does not consistently handle them") % { currentvalue: currentvalue }
       currentvalue = :silly
     end
 
@@ -128,19 +132,17 @@ Puppet::Type.type(:file).provide :posix do
   def mode
     stat = resource.stat
     if stat
-      return (stat.mode & 007777).to_s(8).rjust(4, '0')
+      (stat.mode & 0o07777).to_s(8).rjust(4, '0')
     else
-      return :absent
+      :absent
     end
   end
 
   def mode=(value)
-    begin
-      File.chmod(value.to_i(8), resource[:path])
-    rescue => detail
-      error = Puppet::Error.new(_("failed to set mode %{mode} on %{path}: %{message}") % { mode: mode, path: resource[:path], message: detail.message })
-      error.set_backtrace detail.backtrace
-      raise error
-    end
+    File.chmod(value.to_i(8), resource[:path])
+  rescue => detail
+    error = Puppet::Error.new(_("failed to set mode %{mode} on %{path}: %{message}") % { mode: mode, path: resource[:path], message: detail.message })
+    error.set_backtrace detail.backtrace
+    raise error
   end
 end
