@@ -32,14 +32,14 @@ Puppet::Type.type(:package).provide :pip, :parent => ::Puppet::Provider::Package
   # Required by Puppet::Provider::Package::Targetable::resource_or_provider_command
   def self.provider_command
     # Ensure pip can upgrade pip, which usually puts pip into a new path /usr/local/bin/pip (compared to /usr/bin/pip)
-    self.cmd.map { |c| which(c) }.find { |c| c != nil }
+    cmd.map { |c| which(c) }.find { |c| !c.nil? }
   end
 
   def self.cmd
     if Puppet::Util::Platform.windows?
       ["pip.exe"]
     else
-      ["pip-python", "pip2", "pip-2", "pip2.7"]
+      %w[pip pip-python pip2 pip-2 pip2.7]
     end
   end
 
@@ -65,7 +65,7 @@ Puppet::Type.type(:package).provide :pip, :parent => ::Puppet::Provider::Package
   def self.instances(target_command = nil)
     if target_command
       command = target_command
-      self.validate_command(command)
+      validate_command(command)
     else
       command = provider_command
     end
@@ -74,7 +74,7 @@ Puppet::Type.type(:package).provide :pip, :parent => ::Puppet::Provider::Package
     return packages unless command
 
     command_options = ['freeze']
-    command_version = self.pip_version(command)
+    command_version = pip_version(command)
     if compare_pip_versions(command_version, '8.1.0') >= 0
       command_options << '--all'
     end
@@ -93,7 +93,7 @@ Puppet::Type.type(:package).provide :pip, :parent => ::Puppet::Provider::Package
     # Pip list would also show pip installed version, but "pip list" doesn't exist for older versions of pip (E.G v1.0)
     # Not needed when "pip freeze --all" is available.
     if compare_pip_versions(command_version, '8.1.0') == -1
-      packages << new({:ensure => command_version, :name => File.basename(command), :provider => name, :command => command})
+      packages << new({ :ensure => command_version, :name => File.basename(command), :provider => name, :command => command })
     end
 
     packages
@@ -101,9 +101,12 @@ Puppet::Type.type(:package).provide :pip, :parent => ::Puppet::Provider::Package
 
   # Parse lines of output from `pip freeze`, which are structured as:
   # _package_==_version_ or _package_===_version_
+  # or _package_ @ someURL@_version_
   def self.parse(line)
     if line.chomp =~ /^([^=]+)===?([^=]+)$/
-      {:ensure => $2, :name => $1, :provider => name}
+      { :ensure => Regexp.last_match(2), :name => Regexp.last_match(1), :provider => name }
+    elsif line.chomp =~ /^([^@]+) @ [^@]+@(.+)$/
+      { :ensure => Regexp.last_match(2), :name => Regexp.last_match(1), :provider => name }
     end
   end
 
@@ -116,7 +119,7 @@ Puppet::Type.type(:package).provide :pip, :parent => ::Puppet::Provider::Package
     self.class.instances(command).each do |pkg|
       return pkg.properties if @resource[:name].casecmp(pkg.name).zero?
     end
-    return nil
+    nil
   end
 
   # Return latest version available for current package
@@ -133,12 +136,10 @@ Puppet::Type.type(:package).provide :pip, :parent => ::Puppet::Provider::Package
   end
 
   def self.compare_pip_versions(x, y)
-    begin
-      Puppet::Util::Package::Version::Pip.compare(x, y)
-    rescue PIP_VERSION::ValidationFailure => ex
-      Puppet.debug("Cannot compare #{x} and #{y}. #{ex.message} Falling through default comparison mechanism.")
-      Puppet::Util::Package.versioncmp(x, y)
-    end
+    Puppet::Util::Package::Version::Pip.compare(x, y)
+  rescue PIP_VERSION::ValidationFailure => ex
+    Puppet.debug("Cannot compare #{x} and #{y}. #{ex.message} Falling through default comparison mechanism.")
+    Puppet::Util::Package.versioncmp(x, y)
   end
 
   # Use pip CLI to look up versions from PyPI repositories,
@@ -166,12 +167,12 @@ Puppet::Type.type(:package).provide :pip, :parent => ::Puppet::Provider::Package
     execpipe command_and_options do |process|
       process.collect do |line|
         # PIP OUTPUT: Could not find a version that satisfies the requirement example==versionplease (from versions: 1.2.3, 4.5.6)
-        if line =~ /from versions: (.+)\)/
-          versionList = $1.split(', ').sort do |x,y|
-            self.class.compare_pip_versions(x, y)
-          end
-          return versionList
+        next unless line =~ /from versions: (.+)\)/
+
+        versionList = Regexp.last_match(1).split(', ').sort do |x, y|
+          self.class.compare_pip_versions(x, y)
         end
+        return versionList
       end
     end
     []
@@ -182,17 +183,17 @@ Puppet::Type.type(:package).provide :pip, :parent => ::Puppet::Provider::Package
     self.class.validate_command(command)
 
     Dir.mktmpdir("puppet_pip") do |dir|
-      command_and_options = [self.class.quote(command), 'install', "#{@resource[:name]}", '-d', "#{dir}", '-v']
+      command_and_options = [self.class.quote(command), 'install', (@resource[:name]).to_s, '-d', dir.to_s, '-v']
       command_and_options << install_options if @resource[:install_options]
       execpipe command_and_options do |process|
         process.collect do |line|
           # PIP OUTPUT: Using version 0.10.1 (newest of versions: 1.2.3, 4.5.6)
-          if line =~ /Using version .+? \(newest of versions: (.+?)\)/
-            versionList = $1.split(', ').sort do |x,y|
-              self.class.compare_pip_versions(x, y)
-            end
-            return versionList
+          next unless line =~ /Using version .+? \(newest of versions: (.+?)\)/
+
+          versionList = Regexp.last_match(1).split(', ').sort do |x, y|
+            self.class.compare_pip_versions(x, y)
           end
+          return versionList
         end
       end
       return []
@@ -214,13 +215,13 @@ Puppet::Type.type(:package).provide :pip, :parent => ::Puppet::Provider::Package
     should_range
   end
 
-  def get_install_command_options()
+  def get_install_command_options
     should = @resource[:ensure]
-    command_options = %w{install -q}
+    command_options = %w[install -q]
     command_options += install_options if @resource[:install_options]
 
     if @resource[:source]
-      if String === should
+      if should.is_a?(String)
         command_options << "#{@resource[:source]}@#{should}#egg=#{@resource[:name]}"
       else
         command_options << "#{@resource[:source]}#egg=#{@resource[:name]}"
@@ -235,7 +236,7 @@ Puppet::Type.type(:package).provide :pip, :parent => ::Puppet::Provider::Package
       return command_options
     end
 
-    unless String === should
+    unless should.is_a?(String)
       command_options << @resource[:name]
 
       return command_options
@@ -339,7 +340,7 @@ Puppet::Type.type(:package).provide :pip, :parent => ::Puppet::Provider::Package
   def list_extra_flags(command_version)
     klass = self.class
     if klass.compare_pip_versions(command_version, '20.2.4') == 1 &&
-      klass.compare_pip_versions(command_version, '21.1') == -1
+       klass.compare_pip_versions(command_version, '21.1') == -1
       '--use-deprecated=legacy-resolver'
     end
   end
