@@ -55,9 +55,9 @@ class Puppet::Transaction
 
     @resource_harness = Puppet::Transaction::ResourceHarness.new(self)
 
-    @prefetched_providers = Hash.new { |h,k| h[k] = {} }
+    @prefetched_providers = Hash.new { |h, k| h[k] = {} }
 
-    @prefetch_failed_providers = Hash.new { |h,k| h[k] = {} }
+    @prefetch_failed_providers = Hash.new { |h, k| h[k] = {} }
 
     # With merge_dependency_warnings, notify and warn about class dependency failures ... just once per class. TJK 2019-09-09
     @merge_dependency_warnings = Puppet[:merge_dependency_warnings]
@@ -78,11 +78,9 @@ class Puppet::Transaction
     prerun_errors = {}
 
     @catalog.vertices.each do |res|
-      begin
-        res.pre_run_check
-      rescue Puppet::Error => detail
-        prerun_errors[res] = detail
-      end
+      res.pre_run_check
+    rescue Puppet::Error => detail
+      prerun_errors[res] = detail
     end
 
     unless prerun_errors.empty?
@@ -107,7 +105,7 @@ class Puppet::Transaction
 
     Puppet.info _("Applying configuration version '%{version}'") % { version: catalog.version } if catalog.version
 
-    continue_while = lambda { !stop_processing? }
+    continue_while = -> { !stop_processing? }
 
     post_evalable_providers = Set.new
     pre_process = lambda do |resource|
@@ -149,11 +147,9 @@ class Puppet::Transaction
       end
 
       post_evalable_providers.each do |provider|
-        begin
-          provider.post_resource_eval
-        rescue => detail
-          Puppet.log_exception(detail, _("post_resource_eval failed for provider %{provider}") % { provider: provider })
-        end
+        provider.post_resource_eval
+      rescue => detail
+        Puppet.log_exception(detail, _("post_resource_eval failed for provider %{provider}") % { provider: provider })
       end
 
       persistence.save if persistence.enabled?(catalog)
@@ -222,7 +218,7 @@ class Puppet::Transaction
 
   # Find all of the changed resources.
   def changed?
-    report.resource_statuses.values.find_all { |status| status.changed }.collect { |status| catalog.resource(status.resource) }
+    report.resource_statuses.values.find_all(&:changed).collect { |status| catalog.resource(status.resource) }
   end
 
   def relationship_graph
@@ -247,8 +243,8 @@ class Puppet::Transaction
   def prefetch_if_necessary(resource)
     provider_class = resource.provider.class
     if !provider_class.respond_to?(:prefetch) or
-        prefetched_providers[resource.type][provider_class.name] or
-        prefetch_failed_providers[resource.type][provider_class.name]
+       prefetched_providers[resource.type][provider_class.name] or
+       prefetch_failed_providers[resource.type][provider_class.name]
       return
     end
 
@@ -256,7 +252,7 @@ class Puppet::Transaction
 
     if provider_class == resource.class.defaultprovider
       providerless_resources = resources_by_provider(resource.type, nil)
-      providerless_resources.values.each {|res| res.provider = provider_class.name}
+      providerless_resources.values.each { |res| res.provider = provider_class.name }
       resources.merge! providerless_resources
     end
 
@@ -270,7 +266,7 @@ class Puppet::Transaction
     status = resource_harness.evaluate(resource)
     add_resource_status(status)
     ancestor ||= resource
-    if !(status.failed? || status.failed_to_restart?)
+    unless status.failed? || status.failed_to_restart?
       event_manager.queue_events(ancestor, status.events)
     end
   rescue => detail
@@ -299,7 +295,7 @@ class Puppet::Transaction
     # explosion of edges, we also ended up reporting failures for containers
     # like class and stage.  This is undesirable; while just skipping the
     # output isn't perfect, it is RC-safe. --daniel 2011-06-07
-    is_puppet_class = resource.class == Puppet::Type.type(:whit)
+    is_puppet_class = resource.instance_of?(Puppet::Type.type(:whit))
     # With merge_dependency_warnings, notify about class dependency failures ... just once per class. TJK 2019-09-09
     s = resource_status(resource)
     if s && s.dependency_failed?
@@ -316,7 +312,7 @@ class Puppet::Transaction
         @failed_class_dependencies_already_notified.merge(class_dependencies_to_be_notified)
       else
         unless @merge_dependency_warnings || is_puppet_class
-          s.failed_dependencies.find_all { |d| !(@failed_dependencies_already_notified.include?(d.ref)) }.each do |dep|
+          s.failed_dependencies.find_all { |d| !@failed_dependencies_already_notified.include?(d.ref) }.each do |dep|
             resource.notice _("Dependency %{dep} has failures: %{status}") % { dep: dep, status: resource_status(dep).failed }
             @failed_dependencies_already_notified.add(dep.ref)
           end
@@ -355,7 +351,7 @@ class Puppet::Transaction
 
   # Should we ignore tags?
   def ignore_tags?
-    ! @catalog.host_config?
+    !@catalog.host_config?
   end
 
   def resources_by_provider(type_name, provider_name)
@@ -378,7 +374,7 @@ class Puppet::Transaction
   def prefetch(provider_class, resources)
     type_name = provider_class.resource_type.name
     return if @prefetched_providers[type_name][provider_class.name] ||
-      @prefetch_failed_providers[type_name][provider_class.name]
+              @prefetch_failed_providers[type_name][provider_class.name]
 
     Puppet.debug { "Prefetching #{provider_class.name} resources for #{type_name}" }
     begin
@@ -398,16 +394,16 @@ class Puppet::Transaction
 
   # Is the resource currently scheduled?
   def scheduled?(resource)
-    self.ignoreschedules || resource_harness.scheduled?(resource)
+    ignoreschedules || resource_harness.scheduled?(resource)
   end
 
   # Should this resource be skipped?
   def skip?(resource)
     if skip_tags?(resource)
-      resource.debug "Skipping with skip tags #{skip_tags.join(", ")}"
+      resource.debug "Skipping with skip tags #{skip_tags.join(', ')}"
     elsif missing_tags?(resource)
-      resource.debug "Not tagged with #{tags.join(", ")}"
-    elsif ! scheduled?(resource)
+      resource.debug "Not tagged with #{tags.join(', ')}"
+    elsif !scheduled?(resource)
       resource.debug "Not scheduled"
     elsif failed_dependencies?(resource)
       # When we introduced the :whit into the graph, to reduce the combinatorial
@@ -415,10 +411,10 @@ class Puppet::Transaction
       # like class and stage.  This is undesirable; while just skipping the
       # output isn't perfect, it is RC-safe. --daniel 2011-06-07
       # With merge_dependency_warnings, warn about class dependency failures ... just once per class. TJK 2019-09-09
-      unless resource.class == Puppet::Type.type(:whit)
+      unless resource.instance_of?(Puppet::Type.type(:whit))
         if @merge_dependency_warnings && resource.parent && failed_dependencies?(resource.parent)
           ps = resource_status(resource.parent)
-          ps.failed_dependencies.find_all { |d| !(@failed_class_dependencies_already_warned.include?(d.ref)) }.each do |dep|
+          ps.failed_dependencies.find_all { |d| !@failed_class_dependencies_already_warned.include?(d.ref) }.each do |dep|
             resource.parent.warning _("Skipping resources in class because of failed class dependencies")
             @failed_class_dependencies_already_warned.add(dep.ref)
           end
@@ -450,7 +446,7 @@ class Puppet::Transaction
     return false if ignore_tags?
     return false if tags.empty?
 
-    not resource.tagged?(*tags)
+    !resource.tagged?(*tags)
   end
 
   def skip_tags?(resource)
