@@ -1,8 +1,10 @@
+# frozen_string_literal: true
+
 module Puppet
   Puppet::Type.type(:file).newproperty(:ctime) do
-    desc %q{A read-only state to check the file ctime. On most modern \*nix-like
+    desc %q(A read-only state to check the file ctime. On most modern \*nix-like
       systems, this is the time of the most recent change to the owner, group,
-      permissions, or content of the file.}
+      permissions, or content of the file.)
 
     def retrieve
       current_value = :absent
@@ -13,9 +15,8 @@ module Puppet
       current_value.to_s
     end
 
-    validate do |val|
+    validate do |_val|
       fail "ctime is read-only"
     end
   end
 end
-
