@@ -9,7 +9,7 @@ class Puppet::Util::Profiler::Aggregate < Puppet::Util::Profiler::WallClock
     @metrics_hash = Metric.new
   end
 
-  def shutdown()
+  def shutdown
     super
     @logger.call("AGGREGATE PROFILING RESULTS:")
     @logger.call("----------------------------")
@@ -40,7 +40,7 @@ class Puppet::Util::Profiler::Aggregate < Puppet::Util::Profiler::WallClock
   end
 
   def print_metrics(metrics_hash, prefix)
-    metrics_hash.sort_by {|_k,v| v.time }.reverse_each do |k,v|
+    metrics_hash.sort_by { |_k, v| v.time }.reverse_each do |k, v|
       @logger.call("#{prefix}#{k}: #{v.time} s (#{v.count} calls)")
       print_metrics(metrics_hash[k], "#{prefix}#{k} -> ")
     end
@@ -55,7 +55,7 @@ class Puppet::Util::Profiler::Aggregate < Puppet::Util::Profiler::WallClock
     attr_reader :count, :time
 
     def [](key)
-      if !has_key?(key)
+      unless has_key?(key)
         self[key] = Metric.new
       end
       super(key)
@@ -80,4 +80,3 @@ class Puppet::Util::Profiler::Aggregate < Puppet::Util::Profiler::WallClock
     end
   end
 end
-
